@@ -41,15 +41,8 @@
 #' in newdata (rows) and each cutpoint (column) of the response variable that
 #' defines an event status.
 #' 
-#' Currently, \code{predictSurvProb} methods are available for the following
-#' R-objects: \describe{ \item{}{\code{matrix}} \item{}{\code{aalen},
-#' \code{cox.aalen} from \code{library(timereg)}} \item{}{\code{mfp} from
-#' \code{library(mfp)}} \item{}{\code{phnnet}, \code{survnnet} from
-#' \code{library(survnnet)}} \item{}{\code{rpart} (from \code{library(rpart)})}
-#' \item{}{\code{coxph}, \code{survfit} from \code{library(survival)}}
-#' \item{}{\code{cph}, \code{psm} from \code{library(rms)}}
-#' \item{}{\code{prodlim} from \code{library(prodlim)}} \item{}{\code{glm} from
-#' \code{library(stats)}} }
+#' Currently, \code{predictSurvProb} methods are readily available for 
+#' various survival models, see \code{methods(predictSurvProb)}
 #'
 #' @aliases pec
 #' @param object A named list of prediction models, where allowed entries are
@@ -218,13 +211,13 @@
 #' \code{PredErr}.  } \item{weight}{ The weight used to linear combine the
 #' \code{AppErr} and the \code{BootCvErr} Only if \code{splitMethod} is one of
 #' "Boot632", or "Boot632plus".  } \item{overfit}{ Estimated \code{overfit} of
-#' the model(s).  See Efron \& Tibshirani (1997, Journal of the American
-#' Statistical Association) and Gerds \& Schumacher (2007, Biometrics).  Only
+#' the model(s).  See Efron and Tibshirani (1997, Journal of the American
+#' Statistical Association) and Gerds and Schumacher (2007, Biometrics).  Only
 #' if \code{splitMethod} is one of "Boot632", or "Boot632plus".  }
 #' \item{call}{The call that produced the object} \item{time}{The time points
 #' at which the prediction error curves change.} \item{ipcw.fit}{The fitted
 #' censoring model that was used for re-weighting the Brier score residuals.
-#' See Gerds \& Schumacher (2006, Biometrical Journal)} \item{n.risk}{The
+#' See Gerds and Schumacher (2006, Biometrical Journal)} \item{n.risk}{The
 #' number of subjects at risk for all time points.} \item{models}{The
 #' prediction models fitted in their own data.} \item{cens.model}{The censoring
 #' models.} \item{maxtime}{The latest timepoint where the prediction error
@@ -240,7 +233,7 @@
 #'
 #' Gerds TA, Kattan MW.
 #' Medical Risk Prediction Models: With Ties to Machine Learning.
-#' Chapman & Hall/CRC
+#' Chapman and Hall/CRC
 #' https://www.routledge.com/9781138384477
 #'
 #' Ulla B. Mogensen, Hemant Ishwaran, Thomas A. Gerds (2012).
@@ -348,6 +341,7 @@
 #' # assessing parametric survival models in learn/validation setting
 #' learndat <- SimSurv(50)
 #' testdat <- SimSurv(30)
+#' library(survival)
 #' library(rms)
 #' f1 <- psm(Surv(time,status)~X1+X2,data=learndat)
 #' f2 <- psm(Surv(time,status)~X1,data=learndat)
@@ -431,7 +425,7 @@ pec <- function(object,
 
   # }}}
   # {{{ check and convert object
-  if (class(object)[1]!="list") {
+  if (!inherits(object,"list")) {
       object <- list(object)
   }
   # }}}
@@ -441,7 +435,7 @@ pec <- function(object,
           stop(paste("Argument formula is missing and first model has no usable formula:",as.character(object[[1]]$call$formula)))
       } else{
           ftry <- try(formula <- eval(object[[1]]$call$formula),silent=TRUE)
-          if ((class(ftry)[1]=="try-error") || match("formula",class(formula),nomatch=0)==0)
+          if (inherits(x=ftry,what="try-error") || !inherits(x = formula,what = "formula"))
               stop("Argument formula is missing and first model has no usable formula.")
           else if (verbose)
               warning("Formula missing. Using formula from first model")
@@ -463,7 +457,7 @@ pec <- function(object,
   # {{{ data
   if (missing(data)){
       data <- eval(object[[1]]$call$data)
-      if (match("data.frame",class(data),nomatch=0)==0)
+      if (!inherits(x = data,what = "data.frame"))
           stop("Argument data is missing.")
       else
           if (verbose)
@@ -484,7 +478,7 @@ pec <- function(object,
   ## m <- model.frame(histformula,data,na.action=na.fail)
   m <- model.frame(histformula,data,na.action=na.action)
   response <- model.response(m)
-  if (match("Surv",class(response),nomatch=0)!=0){
+  if (inherits(x = response,what = "Surv")){
       attr(response,"model") <- "survival"
       attr(response,"cens.type") <- "rightCensored"
       model.type <- "survival"
@@ -677,12 +671,12 @@ if (missing(maxtime) || is.null(maxtime))
         extraArgs <- model.args[[f]]
         if (predictHandlerFun=="predictEventProb"){ # competing risks
             pred <- do.call(predictHandlerFun,c(list(object=fit,newdata=data,times=times,cause=cause),extraArgs))
-            if (class(fit)[[1]]%in% c("matrix","numeric")) pred <- pred[neworder,,drop=FALSE]
+            if (inherits(x = fit,what = "matrix")||inherits(x = fit,what = "numeric")) pred <- pred[neworder,,drop=FALSE]
             .C("pecCR",pec=double(NT),as.double(Y),as.double(status),as.double(event),as.double(times),as.double(pred),as.double(ipcw$IPCW.times),as.double(ipcw$IPCW.subjectTimes),as.integer(N),as.integer(NT),as.integer(ipcw$dim),as.integer(is.null(dim(pred))),NAOK=TRUE,PACKAGE="pec")$pec
         }
         else{  # survival
             pred <- do.call(predictHandlerFun,c(list(object=fit,newdata=data,times=times),extraArgs))
-            if (class(fit)[[1]]%in% c("matrix","numeric")) pred <- pred[neworder,,drop=FALSE]
+            if (inherits(x = fit,what = "matrix")||inherits(x = fit,what = "numeric")) pred <- pred[neworder,,drop=FALSE]
             ## u <- list(as.double(Y),as.double(status),as.double(times),as.double(pred),as.double(ipcw$IPCW.times),as.double(ipcw$IPCW.subjectTimes),as.integer(N),as.integer(NT),as.integer(ipcw$dim),as.integer(is.null(dim(pred))))
             ## if (f==2) browser(skipCalls=1)
             .C("pecSRC",pec=double(NT),as.double(Y),as.double(status),as.double(times),as.double(pred),as.double(ipcw$IPCW.times),as.double(ipcw$IPCW.subjectTimes),as.integer(N),as.integer(NT),as.integer(ipcw$dim),as.integer(is.null(dim(pred))),NAOK=TRUE,PACKAGE="pec")$pec
